@@ -1,3 +1,5 @@
+import os
+
 import requests
 
 from .config import MobioEnvironment, UrlConfig
@@ -38,3 +40,23 @@ def get_host_by_merchant_id(
     data = result.get("data", {})
     return data.get("host", MobioEnvironment.PUBLIC_HOST) if data else MobioEnvironment.PUBLIC_HOST
 
+
+def convert_bytes(num):
+    if not num:
+        return "0 bytes"
+    if isinstance(num, str):
+        return num
+    for x in ['bytes', 'KB', 'MB', 'GB', 'TB']:
+        if num < 1024.0:
+            return "%3.1f %s" % (num, x)
+        num /= 1024.0
+
+
+def file_capacity(file_path):
+    """
+    this function will return the file size
+    """
+    if os.path.isfile(file_path):
+        file_info = os.stat(file_path)
+        return file_info.st_size
+    return None
